@@ -12,17 +12,19 @@ for path in sorted(Path("src").glob("**/*.py")):
     full_doc_path = Path("reference", doc_path)
 
     parts = list(module_path.parts)
-    parts[-1] = f"{parts[-1]}.py"
+    if parts[-1] == "__init__":
+        parts = parts[:-1]
+        doc_path = doc_path.with_name("index.md")
+        full_doc_path = full_doc_path.with_name("index.md")
+    elif parts[-1] == "__main__":
+        continue
     nav[parts] = doc_path
 
     with mkdocs_gen_files.open(full_doc_path, "w") as fd:
-        ident = ".".join(module_path.parts)
+        ident = ".".join(parts)
         print("::: " + ident, file=fd)
 
     mkdocs_gen_files.set_edit_path(full_doc_path, path)
 
-nav["mkdocs_autorefs", "references.py"] = "autorefs/references.md"
-nav["mkdocs_autorefs", "plugin.py"] = "autorefs/plugin.md"
-
 with mkdocs_gen_files.open("reference/SUMMARY.md", "w") as nav_file:
     nav_file.writelines(nav.build_literate_nav())
