@@ -23,7 +23,8 @@ instruction:
 """
 import re
 from collections import ChainMap
-from typing import Any, Mapping, MutableMapping, MutableSequence, Tuple
+from typing import Any, MutableSequence, Tuple
+from warnings import warn
 from xml.etree.ElementTree import Element
 
 import yaml
@@ -122,7 +123,7 @@ class AutoDocProcessor(BlockProcessor):
             # The final HTML is inserted as opaque to subsequent processing, and only revealed at the end.
             el.text = self.md.htmlStash.store(html)
             # So we need to duplicate the headings directly (and delete later), just so 'toc' can pick them up.
-            headings = handler.renderer.get_headings()
+            headings = handler.get_headings()
             el.extend(headings)
 
             page = self._autorefs.current_page
@@ -173,13 +174,25 @@ class AutoDocProcessor(BlockProcessor):
         handler_config = self._handlers.get_handler_config(handler_name)
         handler = self._handlers.get_handler(handler_name, handler_config)
 
-        selection, rendering = get_item_configs(handler_config, config)
+        global_options = handler_config.get("options", {})
+        local_options = config.get("options", {})
+        deprecated_global_options = ChainMap(handler_config.get("selection", {}), handler_config.get("rendering", {}))
+        deprecated_local_options = ChainMap(config.get("selection", {}), config.get("rendering", {}))
+
+        options = ChainMap(local_options, deprecated_local_options, global_options, deprecated_global_options)
+
+        if deprecated_global_options or deprecated_local_options:
+            warn(
+                "'selection' and 'rendering' are deprecated and merged into a single 'options' YAML key",
+                DeprecationWarning,
+            )
+
         if heading_level:
-            rendering = ChainMap(rendering, {"heading_level": heading_level})  # like setdefault
+            options = ChainMap(options, {"heading_level": heading_level})  # like setdefault
 
         log.debug("Collecting data")
         try:
-            data: CollectorItem = handler.collector.collect(identifier, selection)
+            data: CollectorItem = handler.collect(identifier, options)
         except CollectionError as exception:
             log.error(str(exception))
             if PluginError is SystemExit:  # When MkDocs 1.2 is sufficiently common, this can be dropped.
@@ -188,12 +201,12 @@ class AutoDocProcessor(BlockProcessor):
 
         if not self._updated_env:
             log.debug("Updating renderer's env")
-            handler.renderer._update_env(self.md, self._config)  # noqa: WPS437 (protected member OK)
+            handler._update_env(self.md, self._config)  # noqa: WPS437 (protected member OK)
             self._updated_env = True
 
         log.debug("Rendering templates")
         try:
-            rendered = handler.renderer.render(data, rendering)
+            rendered = handler.render(data, options)
         except TemplateNotFound as exc:
             theme_name = self._config["theme_name"]
             log.error(
@@ -204,21 +217,6 @@ class AutoDocProcessor(BlockProcessor):
         return rendered, handler, data
 
 
-def get_item_configs(handler_config: dict, config: dict) -> Tuple[Mapping, MutableMapping]:
-    """Get the selection and rendering configuration merged into the global configuration of the given handler.
-
-    Arguments:
-        handler_config: The global configuration of a handler. It can be an empty dictionary.
-        config: The configuration to merge into the global handler configuration.
-
-    Returns:
-        Two dictionaries: selection and rendering. The local configurations are merged into the global ones.
-    """
-    item_selection_config = ChainMap(config.get("selection", {}), handler_config.get("selection", {}))
-    item_rendering_config = ChainMap(config.get("rendering", {}), handler_config.get("rendering", {}))
-    return item_selection_config, item_rendering_config
-
-
 class _PostProcessor(Treeprocessor):
     def run(self, root: Element):
         carry_text = ""
