@@ -127,11 +127,23 @@ def test_use_custom_handler(ext_markdown):
 
 def test_dont_register_every_identifier_as_anchor(plugin):
     """Assert that we don't preemptively register all identifiers of a rendered object."""
-    renderer = plugin._handlers.get_handler("python").renderer  # noqa: WPS437
+    handler = plugin._handlers.get_handler("python")  # noqa: WPS437
     ids = {"id1", "id2", "id3"}
-    renderer.get_anchors = lambda _: ids
+    handler.get_anchors = lambda _: ids
     plugin.md.convert("::: tests.fixtures.headings")
     autorefs = plugin.md.parser.blockprocessors["mkdocstrings"]._autorefs  # noqa: WPS219,WPS437
     for identifier in ids:
         assert identifier not in autorefs._url_map  # noqa: WPS437
         assert identifier not in autorefs._abs_url_map  # noqa: WPS437
+
+
+def test_use_deprecated_yaml_keys(ext_markdown):
+    """Check that using the deprecated 'selection' and 'rendering' YAML keys emits a deprecation warning."""
+    with pytest.warns(DeprecationWarning, match="single 'options' YAML key"):
+        assert "h1" not in ext_markdown.convert("::: tests.fixtures.headings\n    rendering:\n      heading_level: 2")
+
+
+def test_use_new_options_yaml_key(ext_markdown):
+    """Check that using the new 'options' YAML key works as expected."""
+    assert "h1" in ext_markdown.convert("::: tests.fixtures.headings\n    options:\n      heading_level: 1")
+    assert "h1" not in ext_markdown.convert("::: tests.fixtures.headings\n    options:\n      heading_level: 2")
